searchData={"items":[{"type":"module","title":"Digester","doc":"This module represents a utility to calculate a digest deterministically from a set of values.\nIf the order of the elements or their values change, the hash will change.\n\nThis module is useful to support incremental localization based on the hash of the content and\nthe context it depends on.","ref":"Digester.html"},{"type":"function","title":"Digester.combine/2","doc":"Combines the given digestable with the current digester.\nNote that the **order** of the digestables is important. If the same digestables are combined\nbut in a different order, the resulting digest will be different.","ref":"Digester.html#combine/2"},{"type":"function","title":"Digester.finalize/1","doc":"It finalizes the digester and returns the digest as a string.","ref":"Digester.html#finalize/1"},{"type":"function","title":"Examples - Digester.finalize/1","doc":"iex> digester = Digester.new() |> Digester.combine(\"Hello\") |> Digester.combine(\"World\")\n      %Digester{algorithm: :sha256, digestables: [\"78ae647dc5544d227130a0682a51e30bc7777fbb6d8a8f17007463a3ecd1d524\", \"185f8db32271fe25f561a6fc938b2e264306ec304eda518007d1764826381969\"]}\n      iex> Digester.finalize(digester)\n      \"c79df18bcbce0d9501007f33555ef01b9724f0a986b0dc7d872400bd33053a2e\"","ref":"Digester.html#finalize/1-examples"},{"type":"function","title":"Digester.new/1","doc":"Creates a new digester with the given options.","ref":"Digester.html#new/1"},{"type":"function","title":"Options - Digester.new/1","doc":"- `:algorithm` - The algorithm to use for hashing. Defaults to `:sha256`.","ref":"Digester.html#new/1-options"},{"type":"function","title":"Examples - Digester.new/1","doc":"iex> Digester.new()\n    %Digester{algorithm: :sha256, digestables: []}","ref":"Digester.html#new/1-examples"},{"type":"type","title":"Digester.new_opts/0","doc":"","ref":"Digester.html#t:new_opts/0"},{"type":"type","title":"Digester.t/0","doc":"","ref":"Digester.html#t:t/0"},{"type":"extras","title":"Digester","doc":"# Digester\n\n[![Hex.pm](https://img.shields.io/hexpm/v/digester.svg)]()\n[![Hex.pm](https://img.shields.io/hexpm/dt/digester.svg)]()\n[![Hex.pm](https://img.shields.io/hexpm/dw/digester.svg)]()\n[![Hex.pm](https://img.shields.io/hexpm/dd/digester.svg)]()\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n\n`Digester` provides a set of utilities for obtaining **digests** from Elixir primitives. Digests are useful to determine if a value has changed, for example, in a cache.","ref":"readme.html"},{"type":"extras","title":"Installation - Digester","doc":"The package can be installed by adding `digester` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:digester, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Digester","doc":"To obtain a digest from a value or a set of values, you'll have to first create an instance of `Digester`:\n\n```elixir\ndigester = Digester.new() # Defaults to the SHA256 algorithm\n\n# You can specify the algorithm to use\ndigester = Digester.new(:sha256)\n```\n\nThen, you can use `Digester.combine/2` for every value you'd like to include in the digest:\n\n```elixir\ndigester = digester\n  |> Digester.combine(\"foo\")\n  |> Digester.combine(%{bar: \"baz\"})\n```\n\nRemember that **the order** in which you combine values matters, so the following will produce a different digest:\n\n```elixir\ndigester = digester\n  |> Digester.combine(%{bar: \"baz\"})\n  |> Digester.combine(\"foo\")\n```\n\nFinally, you can obtain the digest by calling `Digester.finalize/1`:\n\n```elixir\ndigest = Digester.finalize(digester)\n```\n\n`digest` will be a `String` containing the digest of the values you combined.","ref":"readme.html#usage"}],"content_type":"text/markdown"}